[![PyPI](https://img.shields.io/pypi/v/unilogger?logo=pypi)](https://pypi.org/project/unilogger/)
[![GitHub](https://img.shields.io/github/license/jlu-ilr-hydro/unilogger?logo=github)](https://github.com/jlu-ilr-hydro/unilogger)
[![GitHub last commit](https://img.shields.io/github/last-commit/jlu-ilr-hydro/unilogger?logo=github)](https://github.com/jlu-ilr-hydro/odmfclient)

UniLogger
=========

A uniform wrapper for various sensor systems. 

Currently, ModBus, SDI12 and AddUPI (OTT/ADCON) are supported